@@ -16,20 +16,20 @@
 #
 
 
-import gmail
-import blackberry
-import outlook
-import yahoo
-import lotusnotes
-import iphone
+from unforward.emailclients.gmail import GmailClient
+from unforward.emailclients.blackberry import BlackberryClient
+from unforward.emailclients.outlook import OutlookExpressClient
+from unforward.emailclients.yahoo import YahooClient
+from unforward.emailclients.lotusnotes import LotusNotesClient
+from unforward.emailclients.iphone import iPhoneClient
 
 clients = [
-            gmail.GmailClient,
-            blackberry.BlackberryClient,
-            outlook.OutlookExpressClient,
-            yahoo.YahooClient,
-            lotusnotes.LotusNotesClient,
-            iphone.iPhoneClient,
+            GmailClient,
+            BlackberryClient,
+            OutlookExpressClient,
+            YahooClient,
+            LotusNotesClient,
+            iPhoneClient,
         ]
 
 
