@@ -20,6 +20,8 @@ from unforward.errors import ExtractionError
 from bs4 import BeautifulSoup
 from pprint import pprint
 import datetime
+import dateutil.parser
+import dateutil.tz
 
 class OutlookExpressClient(EmailClient):
     """ Extracts originals from OutlookExpress clients"""
@@ -42,14 +44,14 @@ class OutlookExpressClient(EmailClient):
             if len(blockquotes) > 1:
                 sender = blockquotes[0].a.get_text()
                 body = ''.join(str(tag).strip() for tag in blockquotes[1].contents)
-                datestring = str(blockquotes[0].find_all('b')[1].next_sibling).strip()
-                date = datetime.datetime.strptime(datestring, "%B %d, %Y at %I:%M:%S %p %Z")
+                datestring = str(blockquotes[0].find_all('b')[1].next_sibling).strip().replace("\u00A0", " ")
+                date = dateutil.parser.parse(datestring)
             else:
                 sender = blockquotes[0].a.get_text()
                 bodydivs = blockquotes[0].find_all('div')
                 body = ''.join(str(tag).strip() for tag in bodydivs[-1].contents)
-                datestring = str(bodydivs[2].find_all('span')[1].contents[0]).strip()
-                date = datetime.datetime.strptime(datestring, "%B %d, %Y at %I:%M:%S %p %Z")
+                datestring = str(bodydivs[2].find_all('span')[1].contents[0]).strip().replace("\u00A0", " ")
+                date = dateutil.parser.parse(datestring)
                         
                         
             return {"body" : body, "sender" : sender, "date" : date}
