@@ -27,4 +27,10 @@ class NoForwardFoundError(ValueError):
     """ This Exception is used to indicate that the extractor could not find any forwards
         within the email body."""
     pass
+
+
+class NoHTMLPayloadFound(ValueError):
+    """ This Exception is used to indicate that the extractor could not find any HTML payloads
+        to extract from.."""
+    pass
     
