@@ -24,17 +24,19 @@ from unforward.errors import ExtractionError
 from unforward.errors import NoHTMLPayloadFound
 import logging
 from pprint import pprint
+import codecs
 
 def main():
     """ The main starting point for the unforward script."""
+    sys.stdin = codecs.getreader('utf-8')(sys.stdin)
     extractor = unforward.Extractor()
     try:
         if '--html' in sys.argv:
             sys.argv.remove('--html')
-            email_text = ''.join(line for line in fileinput.input(openhook=fileinput.hook_encoded("utf-8") ) )
+            email_text = ''.join(line for line in fileinput.input( ) )
             result = extractor.extract_from_html(email_text)
         else:    
-            email_text = ''.join(line for line in fileinput.input(openhook=fileinput.hook_encoded("utf-8") ) )
+            email_text = ''.join(line for line in fileinput.input( ) )
             result = extractor.extract(email_text)
         result['date'] = result['date'].strftime(r"%Y-%m-%dT%H:%M:%S %z")
         print(json.dumps(result))
